@@ -55,3 +55,9 @@ class Compressor(object):
         if code != 0:
             raise ValueError('Decompress Image Error! Error code:' + str(code))
         return decompressed_bytes.raw[:decompressed_len.value]
+
+if __name__ == '__main__':
+    raw = 'sadfasfsfdgsfdgsfdgasafdsafasdf'.encode()
+    compressed = Compressor.compress(raw)
+    decompressed = Compressor.decompress(compressed)
+    print(raw==decompressed)
\ No newline at end of file
